@@ -240,6 +240,11 @@ class Printer(AbstractTracker):
         print >> self.file, msg
 
     def set(self, obj_name, attr, value): 
+        """
+        >>> z = Mock('z', show_attrs=True)
+        >>> z.a = 2
+        Set z.a = 2
+        """
         print >> self.file, 'Set %s.%s = %r' % (obj_name, attr, value)
 
 
@@ -524,7 +529,7 @@ class Mock(object):
             object.__setattr__(self, attr, value)
         else:
             if self.mock_show_attrs and self.mock_tracker is not None:
-                self.mock_tracker.set(self.name, attr, value)
+                self.mock_tracker.set(self.mock_name, attr, value)
             self.mock_attrs[attr] = value 
 
 __test__ = {
